//*****************************************************
//*****************************************************
// This program solves RBC model for welfare analysis
// Lastest revision: 29/05/2021
// Email: ding.dong@connect.ust.hk
//*****************************************************
//*****************************************************

// Variables
var Y C I K Kt R V A;
varexo e;

// Parameters
parameters palpha pbeta pdelta prho psigma;
pbeta    = 0.96;                 % discount factor
palpha   = 1/3;                  % capital income share
pdelta   = 0.025;                % capital depreciation rate
prho     = 0.90;                 % persistence of shock
psigma   = 0.05;                 % volatility of shock

// Model
model;

1/C    = pbeta*(1/C(+1))*R(+1);
K      = I + (1- pdelta)*K(-1);
Y      = A*K(-1)^palpha;
I      = Y - C;
R      = palpha*A*(K(-1))^(palpha-1) + 1-pdelta;
V      = log(C) + pbeta*V(+1);
Kt     = K(-1);
log(A) = prho*log(A(-1)) - psigma*e;

end;

// Shock
shocks;
var e = 1;
end;

steady;

stoch_simul(order=1,irf=20,nograph);

